##  Step 1: Create a Python Project
To get started, create a new Python project.

```
poetry new leanix-graphql-tutorial
```



Poetry generates a basic Python project within the leanix-graphql-tutorial directory.
Change your working directory.

```
cd leanix-graphql-tutorial
```



